#
# spec file for package ghc-lens-aeson
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name lens-aeson
Name:           ghc-%{pkg_name}
Version:        1.2.3
Release:        bp156.1.1
Summary:        Law-abiding lenses for aeson
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-short-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
ExcludeArch:    %{ix86}

%description
Law-abiding lenses for aeson.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc AUTHORS.markdown CHANGELOG.markdown README.markdown

%changelog
* Sun Aug 27 2023 Peter Simons <psimons@suse.com>
- Update lens-aeson to version 1.2.3 revision 2.
  1.2.3 [2023.06.27]
  - -----------------
  * Use `aeson`'s `decode` function in the `AsJSON` instance for `ByteString`s.
    This allows removing a direct dependency on `attoparsec`.
  * Allow building with `aeson-2.2`.
  1.2.2 [2022.08.11]
  - -----------------
  * Add `atKey :: AsValue t => Key -> Traversal' t (Maybe Value)`, a variant of
    `key` that uses `at` instead of `ix`.
  1.2.1 [2022.05.07]
  - -----------------
  * Change the `IsKey` instances for `ByteString`s to use
    `decodeUtf8With lenientDecode` instead of `decodeUtf8`. While these `IsKey`
    instances are meant to used for interoperability with `aeson` values that
    are UTF-8–encoded, using `decodeUtf8With lenientDecode` at least ensures
    that converting a non–UTF-8–encoded `ByteString` will not crash.
  1.2 [2022.03.19]
  - ---------------
  * Require `aeson-2.0.2.*` and `lens-5.0.*` or greater.
  * Change the types of `_Object`, `key`, and `members`:
    ```diff
  - _Object :: Prism' t (HashMap Text Value)
    +_Object :: Prism' t (KeyMap Value)
  - key :: AsValue t => Text -> Traversal' t Value
    +key :: AsValue t => Key  -> Traversal' t Value
  - members :: AsValue t => IndexedTraversal' Text t Value
    +members :: AsValue t => IndexedTraversal' Key  t Value
    ```
    This mirrors similar changes made in `aeson-2.0.*`, where the type of
    `Object`'s field was changed from `HashMap Text Value` to `KeyMap Value`.
    The `Ixed Value` instance changes similarly:
    ```diff
  - type instance Index Value = Text
    +type instance Index Value = Key
    ```
  * Remove `Primitive` and `AsPrimitive`, since https://tools.ietf.org/html/rfc7159
    de-emphasized the notion of primitive versus composite JSON values.
  * The `AsPrimitive` methods (`_Value`, `_String`, and `_Bool`) are now
    `AsValue` methods.
  * `_Number`'s default signature, `Bool_`, `String_`, and `Null_` now have an
    `AsValue` constraint.
  * Add `Wrapped` and `Rewrapped` instances for `KeyMap`. These treat `KeyMap v`
    as a wrapper around `[(Key, v)]`. The order in which the key-value pairs
    appear in this list is not stable.
  * Add an `IsKey` class, whose method `_Key` is an `Iso` for converting values
    to and from a `Key`.
* Sun Dec 26 2021 Peter Simons <psimons@suse.com>
- Update lens-aeson to version 1.1.3 revision 1.
  1.1.3 [2021.11.16]
  - -----------------
  * Drop support for pre-8.0 versions of GHC.
* Sun Oct 10 2021 psimons@suse.com
- Update lens-aeson to version 1.1.2.
  1.1.2 [2021.10.09]
  - -----------------
  * Allow building with `aeson-2.0.0.0`.
  * Add `Index`, `IxValue`, `Ixed`, `At`, and `Each` instances for `KeyMap` if
    building with `aeson-2.0.0.0` or later.
* Tue Mar 23 2021 psimons@suse.com
- Update lens-aeson to version 1.1.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Feb 19 2021 psimons@suse.com
- Update lens-aeson to version 1.1.1.
  1.1.1 [2021.02.17]
  - -----------------
  * Allow building with `lens-5.*`.
  * The build-type has been changed from `Custom` to `Simple`.
    To achieve this, the `doctests` test suite has been removed in favor of using
    [`cabal-docspec`](https://github.com/phadej/cabal-extras/tree/master/cabal-docspec)
    to run the doctests.
* Mon Feb  8 2021 psimons@suse.com
- Update lens-aeson to version 1.1 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Thu Dec 17 2020 psimons@suse.com
- Update lens-aeson to version 1.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Nov 29 2020 psimons@suse.com
- Add lens-aeson at version 1.1 revision 2.
